# gem5art tasks package

This package contains a [Celery](http://www.celeryproject.org/) worker and tasks for running gem5.
This package implicitly depends on the gem5art run package.

See [gem5art](https://github.com/darchr/gem5art) repo for more details.
